@@ -25,8 +25,6 @@
 
 #include "config.h"
 
-#include <glib/gi18n.h>
-
 #include <telepathy-glib/util.h>
 
 #define GOA_API_IS_SUBJECT_TO_CHANGE /* awesome! */
@@ -150,6 +148,8 @@ get_tp_parameters (GoaAccount *account)
       PARAM ("param-account", "messenger.live.com");
       PARAM ("param-require-encryption", "true");
       PARAM ("param-fallback-servers", "xmpp.messenger.live.com");
+      PARAM ("param-extra-certificate-identities",
+          "*.gateway.messenger.live.com");
     }
   else
     {
