@@ -4,6 +4,8 @@
 
 #include <glib/gi18n-lib.h>
 
+#include <libempathy/empathy-contact-groups.h>
+
 #include <libempathy-gtk/empathy-roster-contact.h>
 #include <libempathy-gtk/empathy-roster-group.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
@@ -200,6 +202,9 @@ group_expanded_cb (EmpathyRosterGroup *group,
     }
 
   g_list_free (widgets);
+
+  empathy_contact_group_set_expanded (empathy_roster_group_get_name (group),
+      gtk_expander_get_expanded (GTK_EXPANDER (group)));
 }
 
 static EmpathyRosterGroup *
@@ -226,6 +231,9 @@ ensure_roster_group (EmpathyRosterView *self,
   else
     roster_group = empathy_roster_group_new (group, NULL);
 
+  gtk_expander_set_expanded (GTK_EXPANDER (roster_group),
+      empathy_contact_group_get_expanded (group));
+
   g_signal_connect (roster_group, "notify::expanded",
       G_CALLBACK (group_expanded_cb), self);
 
@@ -238,6 +246,53 @@ ensure_roster_group (EmpathyRosterView *self,
   return EMPATHY_ROSTER_GROUP (roster_group);
 }
 
+static void
+update_empty (EmpathyRosterView *self,
+    gboolean empty)
+{
+  if (self->priv->empty == empty)
+    return;
+
+  self->priv->empty = empty;
+  g_object_notify (G_OBJECT (self), "empty");
+}
+
+static gboolean filter_group (EmpathyRosterView *self,
+    EmpathyRosterGroup *group);
+
+static gboolean
+at_least_one_group_displayed (EmpathyRosterView *self)
+{
+  GHashTableIter iter;
+  gpointer v;
+
+  g_hash_table_iter_init (&iter, self->priv->roster_groups);
+  while (g_hash_table_iter_next (&iter, NULL, &v))
+    {
+      EmpathyRosterGroup *group = EMPATHY_ROSTER_GROUP (v);
+
+      if (filter_group (self, group))
+        return TRUE;
+    }
+
+  return FALSE;
+}
+
+static void
+check_if_empty (EmpathyRosterView *self)
+{
+  /* Roster is considered as empty if there is no contact *and* no group
+   * currently displayed. */
+  if (g_hash_table_size (self->priv->displayed_contacts) != 0 ||
+      at_least_one_group_displayed (self))
+    {
+      update_empty (self, FALSE);
+      return;
+    }
+
+  update_empty (self, TRUE);
+}
+
 static void
 update_group_widgets (EmpathyRosterView *self,
     EmpathyRosterGroup *group,
@@ -254,7 +309,11 @@ update_group_widgets (EmpathyRosterView *self,
     count = empathy_roster_group_remove_widget (group, GTK_WIDGET (contact));
 
   if (count != old_count)
-    egg_list_box_child_changed (EGG_LIST_BOX (self), GTK_WIDGET (group));
+    {
+      egg_list_box_child_changed (EGG_LIST_BOX (self), GTK_WIDGET (group));
+
+      check_if_empty (self);
+    }
 }
 
 static void
@@ -270,6 +329,9 @@ add_to_group (EmpathyRosterView *self,
   if (contacts == NULL)
     return;
 
+  if (g_hash_table_lookup (contacts, group) != NULL)
+    return;
+
   if (tp_strdiff (group, NO_GROUP))
     roster_group = ensure_roster_group (self, group);
 
@@ -283,6 +345,32 @@ add_to_group (EmpathyRosterView *self,
     }
 }
 
+static void
+individual_favourite_change_cb (FolksIndividual *individual,
+    GParamSpec *spec,
+    EmpathyRosterView *self)
+{
+  /* We may have to refilter the contact as only favorite contacts are always
+   * displayed regardless of their presence. */
+  GHashTable *contacts;
+  GtkWidget *contact;
+
+  contacts = g_hash_table_lookup (self->priv->roster_contacts, individual);
+  if (contacts == NULL)
+    return;
+
+  if (self->priv->show_groups)
+    contact = g_hash_table_lookup (contacts,
+        EMPATHY_ROSTER_MODEL_GROUP_TOP_GROUP);
+  else
+    contact = g_hash_table_lookup (contacts, NO_GROUP);
+
+  if (contact == NULL)
+    return;
+
+  egg_list_box_child_changed (EGG_LIST_BOX (self), contact);
+}
+
 static void
 individual_added (EmpathyRosterView *self,
     FolksIndividual *individual)
@@ -323,6 +411,9 @@ individual_added (EmpathyRosterView *self,
 
       g_list_free (groups);
     }
+
+  tp_g_signal_connect_object (individual, "notify::is-favourite",
+      G_CALLBACK (individual_favourite_change_cb), self, 0);
 }
 
 static void
@@ -500,7 +591,8 @@ contact_in_top (EmpathyRosterView *self,
       groups = empathy_roster_model_get_groups_for_individual (
           self->priv->model, individual);
 
-      if (g_list_find (groups, EMPATHY_ROSTER_MODEL_GROUP_TOP_GROUP) != NULL)
+      if (g_list_find_custom (groups, EMPATHY_ROSTER_MODEL_GROUP_TOP_GROUP,
+            (GCompareFunc) g_strcmp0) != NULL)
         result = TRUE;
 
       g_list_free (groups);
@@ -682,17 +774,6 @@ is_searching (EmpathyRosterView *self)
   return gtk_widget_get_visible (GTK_WIDGET (self->priv->search));
 }
 
-static void
-update_empty (EmpathyRosterView *self,
-    gboolean empty)
-{
-  if (self->priv->empty == empty)
-    return;
-
-  self->priv->empty = empty;
-  g_object_notify (G_OBJECT (self), "empty");
-}
-
 static void
 add_to_displayed (EmpathyRosterView *self,
     EmpathyRosterContact *contact)
@@ -739,8 +820,18 @@ remove_from_displayed (EmpathyRosterView *self,
 {
   g_hash_table_remove (self->priv->displayed_contacts, contact);
 
-  if (g_hash_table_size (self->priv->displayed_contacts) == 0)
-    update_empty (self, TRUE);
+  check_if_empty (self);
+}
+
+static gboolean
+contact_is_favorite (EmpathyRosterContact *contact)
+{
+  FolksIndividual *individual;
+
+  individual = empathy_roster_contact_get_individual (contact);
+
+  return folks_favourite_details_get_is_favourite (
+      FOLKS_FAVOURITE_DETAILS (individual));
 }
 
 /**
@@ -765,7 +856,9 @@ contact_should_be_displayed (EmpathyRosterView *self,
   if (self->priv->show_offline)
       return TRUE;
 
-  if (contact_in_top (self, contact))
+  if (contact_in_top (self, contact) &&
+      contact_is_favorite (contact))
+    /* Favorite top contacts are always displayed */
     return TRUE;
 
   return empathy_roster_contact_is_online (contact);
@@ -929,6 +1022,9 @@ empathy_roster_view_constructed (GObject *object)
 
   g_assert (EMPATHY_IS_ROSTER_MODEL (self->priv->model));
 
+  /* Get saved group states. */
+  empathy_contact_groups_get_all ();
+
   populate_view (self);
 
   tp_g_signal_connect_object (self->priv->model, "individual-added",
@@ -1284,12 +1380,12 @@ empathy_roster_view_show_offline (EmpathyRosterView *self,
 static void
 clear_view (EmpathyRosterView *self)
 {
-  gtk_container_foreach (GTK_CONTAINER (self),
-      (GtkCallback) gtk_widget_destroy, NULL);
-
   g_hash_table_remove_all (self->priv->roster_contacts);
   g_hash_table_remove_all (self->priv->roster_groups);
   g_hash_table_remove_all (self->priv->displayed_contacts);
+
+  gtk_container_foreach (GTK_CONTAINER (self),
+      (GtkCallback) gtk_widget_destroy, NULL);
 }
 
 void
