@@ -197,6 +197,10 @@ void empathy_account_settings_set_storage_provider (
     EmpathyAccountSettings *self,
     const gchar *storage);
 
+void empathy_account_settings_set_remember_password (
+    EmpathyAccountSettings *self,
+    gboolean remember);
+
 G_END_DECLS
 
 #endif /* #ifndef __EMPATHY_ACCOUNT_SETTINGS_H__*/
